// java wrapper for vtkTableToSQLiteWriter object
//

package vtk;
import vtk.*;

public class vtkTableToSQLiteWriter extends vtkTableToDatabaseWriter
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetInput_2();
  public vtkTable GetInput() {
    long temp = GetInput_2();

    if (temp == 0) return null;
    return (vtkTable)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInput_3(int id0);
  public vtkTable GetInput(int id0) {
    long temp = GetInput_3(id0);

    if (temp == 0) return null;
    return (vtkTable)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkTableToSQLiteWriter() { super(); }

  public vtkTableToSQLiteWriter(long id) { super(id); }
  public native long   VTKInit();

}
